# Generated by Django 4.2.3 on 2023-10-14 12:32

from django.db import migrations
import djangoldp.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_profile', '0008_alter_profile_available'),
    ]

    operations = [
        migrations.AlterField(
            model_name='profile',
            name='urlid',
            field=djangoldp.fields.LDPUrlField(blank=True, db_index=True, null=True, unique=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.29 on 2020-05-06 08:38
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_profile', '0003_auto_20200416_1157'),
    ]

    operations = [
        migrations.AlterField(
            model_name='profile',
            name='slug',
            field=models.SlugField(blank=True, unique=True),
        ),
    ]



from django.conf import settings
from django.db import models
from django.db.models.signals import post_save
from django.dispatch import receiver
from djangoldp.models import Model
from djangoldp.permissions import ReadOnly, OwnerPermissions

class Profile(Model):
    user = models.OneToOneField(settings.AUTH_USER_MODEL, on_delete=models.CASCADE, related_name="profile")
    slug = models.SlugField(unique=True, blank=True)
    available = models.BooleanField(null=True, blank=True)
    job = models.CharField(max_length=150, blank=True)
    city = models.CharField(max_length=255, blank=True)
    phone = models.CharField(max_length=255, blank=True)
    website = models.URLField(blank=True)

    def jabberID(self):
        try:
            return self.user.chatProfile.jabberID
        except:
            return None

    class Meta:
        auto_author = 'user'
        permission_classes = [ReadOnly|OwnerPermissions]
        lookup_field = 'slug'


    def __str__(self):
        return '{} ({})'.format(self.user.get_full_name(), self.user.username)


@receiver(post_save, sender=settings.AUTH_USER_MODEL)
def create_user_profile(sender, instance, created, **kwargs):
    if created:
        Profile.objects.create(user=instance, slug=instance.username)
    else:
        try:
            instance.profile.slug = instance.username
            instance.profile.save()
        except:
            pass



# Generated by Django 4.2.3 on 2023-07-10 13:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_profile', '0007_auto_20200617_1817'),
    ]

    operations = [
        migrations.AlterField(
            model_name='profile',
            name='available',
            field=models.BooleanField(blank=True, null=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-09-17 11:41
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import djangoldp.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_profile', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='profile',
            name='urlid',
            field=djangoldp.fields.LDPUrlField(blank=True, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name='profile',
            name='user',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='profile', to=settings.AUTH_USER_MODEL),
        ),
    ]



from django.contrib import admin
from djangoldp.admin import DjangoLDPAdmin
from djangoldp.models import Model
from .models import Profile


@admin.register(Profile)
class ProfileAdmin(DjangoLDPAdmin):
    list_display = ('urlid', 'user')
    exclude = ('urlid', 'user', 'is_backlink', 'allow_create_backlink', 'slug')
    search_fields = ['urlid', 'user__urlid', 'available', 'job', 'city', 'phone', 'website']
    ordering = ['urlid']

    def get_queryset(self, request):
        # Hide distant profiles
        queryset = super(ProfileAdmin, self).get_queryset(request)
        internal_ids = [x.pk for x in queryset if not Model.is_external(x)]
        return queryset.filter(pk__in=internal_ids)





# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-09-12 18:55
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Profile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.SlugField(unique=True)),
                ('available', models.NullBooleanField()),
                ('bio', models.CharField(blank=True, max_length=150)),
                ('city', models.CharField(blank=True, max_length=255)),
                ('phone', models.CharField(blank=True, max_length=255)),
                ('website', models.URLField(blank=True)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='profile', to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]



from django.core.management.base import BaseCommand, CommandError
from djangoldp_profile.factories import ProfileFactory
from django.contrib.auth.models import User

class Command(BaseCommand):
    help = 'Mock data'

    def handle(self, *args, **options):
        for user in User.objects.filter(profile__isnull=True):
            ProfileFactory.create(user=user);

        self.stdout.write(self.style.SUCCESS('Successful data mock install'))



# -*- coding: utf-8 -*-
# Generated by Django 1.11.29 on 2020-04-16 11:57
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_profile', '0002_auto_20190917_1141'),
    ]

    operations = [
        migrations.RenameField(
            model_name='profile',
            old_name='bio',
            new_name='job',
        ),
    ]



import factory
from .models import Profile
from djangoldp.factories import UserFactory
from django.db.models.signals import post_save

@factory.django.mute_signals(post_save)
class ProfileFactory(factory.django.DjangoModelFactory):
    class Meta:
        model = Profile

    user = factory.SubFactory(UserFactory)
    available = factory.Faker('null_boolean')
    job = factory.Faker('text', max_nb_chars=145)
    city = factory.Faker('city')
    phone = factory.Faker('phone_number')
    website = factory.Faker('url')
